<?php

function _pp_update_6006() {
  $ret = array();
  
  // Enable new module pp_ig. Also do the database table install
  // This should also create the vocabulary for image galleries
  if (!module_exists('pp_ig')) {
    module_enable(array('pp_ig'));
    if (drupal_get_installed_schema_version('pp_ig') == SCHEMA_UNINSTALLED) {
      drupal_install_modules(array('pp_ig'));
    }
    $ret[] = array('success' => TRUE, 'query' => t('Enabled module ProsePoint Image Gallery.')); 
  }

  // Adjust taxonomy weight for ifimage type
  $content_extra_weights_ifimage = variable_get('content_extra_weights_ifimage', array('body_field' => 0, 'menu' => 1));
  $content_extra_weights_ifimage['taxonomy'] = 1;
  variable_set('content_extra_weights_ifimage', $content_extra_weights_ifimage);

  // Fill in new permissions: 
  require_once(PROSEPOINT_PROFILE_DIR . '/includes/prosepoint.permissions.inc');

  // Add 'access pp image galleries' to anon and auth
  prosepoint_add_permission(1, 'access pp image galleries');
  prosepoint_add_permission(2, 'access pp image galleries');
  $ret[] = array('success' => TRUE, 'query' => t('Added permission access pp image galleries to anonymous and authenticated users.')); 

  // Add 'administer pp image galleries' to editors
  prosepoint_add_permission(4, 'administer pp image galleries');
  $ret[] = array('success' => TRUE, 'query' => t('Added permission administer pp image galleries to editor users.')); 

  // Add 'administer pp image galleries' to administrators
  $admin_rid = prosepoint_get_admin_rid();
  if ($admin_rid) {
    prosepoint_add_permission($admin_rid, 'administer pp image galleries');
    $ret[] = array('success' => TRUE, 'query' => t('Added permission administer pp image galleries to administrator users.')); 
  }
  else {
    drupal_set_message(t('Unable to locate administrator role to patch permissions. Please contact www.prosepoint.org for further help.'), 'warning');
  }

  // Add new variable: 'pp_ig_gallery_thumbnail_preset'
  variable_set('pp_ig_gallery_thumbnail_preset', 'square');

  // Direct pathauto not to create aliases for image galleries
  $vocab_id = variable_get('pp_ig_gallery_vocabulary', FALSE);
  if ($vocab_id) {
    variable_set('pathauto_taxonomy_' . $vocab_id . '_pattern', 'image_gallery/[tid]');
  }
  
  return $ret;
}


function _pp_update_6007() {
  $ret = array();

  // Fill in variable pp_show_story_list_for_source
  variable_set('pp_show_story_list_for_source', 1);

  // Enable module poormanscron
  if (!module_exists('poormanscron')) {
    module_enable(array('poormanscron'));
    $ret[] = array('success' => TRUE, 'query' => t('Enabled module Poorsmancron.')); 
  }

  return $ret;
}


function _pp_update_6008() {
  $ret = array();

  // Make pp_ch_channel_vocabulary handled by pp_ch.module
  $vocab = taxonomy_vocabulary_load(variable_get('pp_ch_channel_vocabulary', '--'));
  if ($vocab) {
    $vocab->module = 'pp_ch';
    $vocab = (array) $vocab;
    taxonomy_save_vocabulary($vocab);
  }

  // Adjust menu paths and url aliases for story listing channels.
  // Move path from taxonomy/term/N to channel/N/stories.
  $channels = pp_ch_get_channels();
  foreach ($channels as $term) {
    $channel = pp_ch_load($term->tid);
    if (empty($channel['editions_enable'])) {
      $oldpath = 'taxonomy/term/' . $term->tid;
      $newpath = 'channel/' . $term->tid . '/stories';
      
      $alias = drupal_get_path_alias($oldpath, '');
      if ($oldpath != $alias) {
        // Change alias from oldpath to newpath
        path_set_alias($oldpath, null);
        path_set_alias($newpath, $alias);
      }

      $menu_name = variable_get('menu_default_node_menu', 'primary-links');  
      $mlid = db_result(db_query_range("SELECT mlid FROM {menu_links} WHERE link_path = '%s' AND menu_name = '%s' AND module = 'menu' ORDER BY mlid ASC", $oldpath, $menu_name, 0, 1));
      if (!$mlid) {
        $mlid = db_result(db_query_range("SELECT mlid FROM {menu_links} WHERE link_path = '%s' AND module = 'menu' ORDER BY mlid ASC", $oldpath, 0, 1));
      }
      if ($mlid) {
        $m = menu_link_load($mlid);
        if ($m) {
          // Change link_path from oldpath to newpath
          $m['link_path'] = $newpath;
          menu_link_save($m);
        }
      }

      // If the frontpage was pointing to oldpath, now point it to newpath
      $frontpage = variable_get('site_frontpage', 'node');
      if ($frontpage == $oldpath) {
        variable_set('site_frontpage', $newpath);
      }
    }
  }
  $ret[] = array('success' => TRUE, 'query' => t('Adjusted menu items and aliases for story listing channels.')); 

  return $ret;
}

