<?php
/*
 * Copyright 2008 ThinkLeft (thinkleft.com.au)
 * Copyright 2008 ProsePoint (www.prosepoint.org)
 */

function pp_ed_teaser_image_settings_form() {
  $form = array();

  $form['img_extract'] = array(
    '#title' => t('Teaser image extraction'),
    '#type' => 'fieldset',
    '#description' => t('These settings affect how teaser images are extracted into a separate display field.'), 
    '#collapsible' => TRUE,
  );
  $form['img_extract']['pp_ed_img_extract_types'] = array(
    '#title' => t('Types'),
    '#type' => 'checkboxes',
    '#multiple' => TRUE,
    '#description' => t('The content types that teaser image extraction should apply to.'),
    '#options' => node_get_types('names'),    
    '#default_value' => variable_get('pp_ed_img_extract_types', array()),
  );
  $form['img_extract']['pp_ed_img_extract_preset'] = array(
    '#title' => t('Teaser image size'),
    '#type' => 'select',
    '#description' => t('The image size that teaser images should be converted to.'),
    '#options' => pp_image_presets_select(),
    '#default_value' => variable_get('pp_ed_img_extract_preset', 'image'),
  );
  $form['img_extract']['pp_ed_img_extract_weight'] = array(
    '#title' => t('Weight'),    
    '#type' => 'weight',
    '#description' => t('The weight of the extracted display field.'),
    '#default_value' => variable_get('pp_ed_img_extract_weight', 0),
  );
  return system_settings_form($form);
}

function pp_ed_editor_settings_form() {
  $form = array();

  $form['visibility'] = array(
    '#title' => t('Editor visibility settings'),
    '#type' => 'fieldset',
    '#description' => t('These settings affect where the visual editor appears.'),
    '#collapsible' => TRUE,
  );
  $form['visibility']['pp_ed_edit_comments'] = array(
    '#title' => t('Use the visual editor for comments'),
    '#type' => 'checkbox',
    '#default_value' => variable_get('pp_ed_edit_comments', FALSE),
  );

  $form['display_settings'] = array(
    '#title' => t('Inserted images and media display settings'),
    '#type' => 'fieldset',
    '#description' => t('These settings affect how inserted images and media are displayed.'), 
    '#collapsible' => TRUE,
  );
  $form['display_settings']['pp_ed_caption_space'] = array(
    '#title' => t('Caption space'),
    '#type' => 'textfield',
    '#field_suffix' => 'px',    
    '#size' => 4,
    '#description' => t('This is the amount of spacing around inserted images or media when there is a caption supplied. This has no effect on media or images without a caption.'),
    '#default_value' => variable_get('pp_ed_caption_space', 10),
  );
  
  $form['#submit'] = array('pp_ed_editor_settings_form_submit');
    
  return system_settings_form($form);
}

function pp_ed_editor_settings_form_validate($form, &$form_state) {
  if (!is_numeric($form_state['values']['pp_ed_caption_space']) || $form_state['values']['pp_ed_caption_space'] < 0) {
    form_set_error('pp_ed_caption_space', t('Caption space must be a nonnegative number.'));
  }
}

function pp_ed_editor_settings_form_submit($form, &$form_state) {
  // This is borrowed from the second half of drupal_flush_all_caches()
  $core = array('cache', 'cache_block', 'cache_filter', 'cache_page');
  $cache_tables = array_merge(module_invoke_all('flush_caches'), $core);
  foreach ($cache_tables as $table) {
    cache_clear_all('*', $table, TRUE);
  }
}
